# -*- coding: utf8 -*-

from optparse import make_option

from django.core.mail import send_mail
from django.core.management.base import BaseCommand
from gestion.inscriptions.models import Inscription


class Command(BaseCommand):
    help = "Retourne les inscriptions en attente"

    option_list = BaseCommand.option_list + (
        make_option(
            "--mail",
            action="store_true",
            default=False,
            dest="mail",
            help="Envoie la liste sur les aliases `inscription` et `root`",
        ),
    )

    def handle(self, *args, **options):
        self.mail_nouvelle_inscription(options["mail"])
        self.mail_inscription_effective(options["mail"])

    adresse_inscripton = "inscription@bde.inp-toulouse.fr"
    adresse_root = "root@bde.inp-toulouse.fr"
    sujet_new_inscription = "Inscription(s) en attente"
    sujet_attente = "Inscription(s) en attente d'inscription effective"

    def to_string_inscription(self, instance):
        return f" - {instance.nom} {instance.prenom} de l'{instance.ecole}"

    def corps_mail(self, en_attente):
        liste_ecole = {str(i.ecole) for i in en_attente}
        msg = "Ecole concernée : {} \n\nListe : \n{}".format(
            "".join(i + " " for i in liste_ecole),
            "".join(self.to_string_inscription(i) + "\n" for i in en_attente),
        )
        return msg

    def mail_nouvelle_inscription(self, mail=False):

        en_attente = Inscription.objects.filter(etat=0).order_by("ecole")

        if en_attente:
            msg = self.corps_mail(en_attente)
            if mail:
                send_mail(
                    self.sujet_new_inscription,
                    msg,
                    self.adresse_inscripton,
                    [self.adresse_inscripton],
                    fail_silently=False,
                )
            else:
                print(self.sujet_new_inscription)
                print(msg + "\n\n")

    def mail_inscription_effective(self, mail=False):

        en_attente = Inscription.objects.filter(etat=2).order_by("ecole")

        if en_attente:
            msg = self.corps_mail(en_attente)
            if mail:
                send_mail(
                    self.sujet_attente,
                    msg,
                    self.adresse_inscripton,
                    [self.adresse_root],
                    fail_silently=False,
                )
            else:
                print(self.sujet_attente)
                print(msg + "\n\n")
